OC.L10N.register(
    "core",
    {
    "Please select a file." : "Ju lutem përzgjidhni një skedar.",
    "File is too big" : "Skedari është shumë i madh",
    "The selected file is not an image." : "Skedari i zgjedhur nuk është një imazh",
    "The selected file cannot be read." : "Skedari i zgjedhur nuk mund të lexohet",
    "Invalid file provided" : "U dha kartelë e pavlefshme",
    "No image or file provided" : "S’u dha figurë apo kartelë",
    "Unknown filetype" : "Lloj i panjohur kartele",
    "Invalid image" : "Figurë e pavlefshme",
    "An error occurred. Please contact your admin." : "Ndodhi një gabim. Ju lutemi, lidhuni me përgjegjësin tuaj.",
    "No temporary profile picture available, try again" : "S’ka gati foto të përkohshme profili, riprovoni",
    "No crop data provided" : "S’u dhanë të dhëna qethjeje",
    "No valid crop data provided" : "S’u dhanë të dhëna qethjeje të vlefshme",
    "Crop is not square" : "Prerja s’është katrore",
    "State token does not match" : "Shenja shtetërore nuk përputhet",
    "Password reset is disabled" : "Opsioni për rigjenerimin e fjalëkalimit është çaktivizuar",
    "Couldn't reset password because the token is invalid" : "S’u ricaktua dot fjalëkalimi, ngaqë token-i është i pavlefshëm",
    "Couldn't reset password because the token is expired" : "S’u ricaktua dot fjalëkalimi, ngaqë token-i ka skaduar",
    "%s password reset" : "U ricaktua fjalëkalimi për %s",
    "Password reset" : "Fjalkalimi u rivendos",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Klikoni butonin më poshtë për të rivendosur fjalëkalimin tuaj. Nëse nuk keni kërkuar rivendosjen e fjalëkalimit, atëherë injorojeni këtë email.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Klikoni ne 'link-un' e rradhes per te rivendosur fjalekalimin tuaj.Nese nuk e keni vendosur akoma fjalekalimin atehere mos e merrni parasysh kete email.",
    "Reset your password" : "Rivendosni nje fjalekalim te ri",
    "Preparing update" : "Duke përgatitur përditësimin",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Ju lutemi, përdorni përditësuesin e rreshtit të urdhrave, sepse përditësimi i vetvetishëm është i çaktivizuar te config.php.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Po kontrollohet tabela %s",
    "Turned on maintenance mode" : "Mënyra e mirëmbajtjes u aktivizua",
    "Turned off maintenance mode" : "Mënyra e mirëmbajtjes u çaktivizua",
    "Maintenance mode is kept active" : "Mënyra mirëmbajtje është mbajtur e aktivizuar",
    "Updating database schema" : "Po përditësohet skema e bazës së të dhënave",
    "Updated database" : "U përditësua baza e të dhënave",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Po kontrollohet nëse mund të përditësohet skema e bazës së të dhënave (kjo mund të hajë shumë kohë, varet nga madhësia e bazës së të dhënave)",
    "Checked database schema update" : "U kontrollua përditësimi i skemës së bazës së të dhënave",
    "Checking updates of apps" : "Po kontrollohen përditësime të aplikacionit",
    "Checking for update of app \"%s\" in appstore" : "Duke kontrolluar për përditësim të aplikacionit \"%s\" në appstore.",
    "Update app \"%s\" from appstore" : "Përditëso aplikacionin \"%s\" nga appstore",
    "Checked for update of app \"%s\" in appstore" : "Duke kontrolluar për përditësim të aplikacionit \"%s\" në appstore.",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Po kontrollohet nëse mund të përditësohet skema e bazës së të dhënave për %s (kjo mund të hajë shumë kohë, varet nga madhësia e bazës së të dhënave)",
    "Checked database schema update for apps" : "U kontrollua përditësimi i skemës së bazës së të dhënave për aplikacionet",
    "Set log level to debug" : "Caktoni shkallë regjistrimi për diagnostikimin",
    "Reset log level" : "Rikthe te parazgjedhja shkallën e regjistrimit",
    "Starting code integrity check" : "Po fillohet kontroll integriteti për kodin",
    "Finished code integrity check" : "Përfundoi kontrolli i integritetit për kodin",
    "%s (incompatible)" : "%s (e papërputhshme)",
    "Following apps have been disabled: %s" : "Janë çaktivizuar aplikacionet vijuese : %s",
    "Already up to date" : "Tashmë e përditësuar",
    "Very weak password" : "Fjalëkalim shumë i dobët",
    "Weak password" : "Fjalëkalim i dobët",
    "So-so password" : "Fjalëkalim çka",
    "Good password" : "Fjalëkalim i mirë",
    "Strong password" : "Fjalëkalim i fortë",
    "Error occurred while checking server setup" : "Ndodhi një gabim gjatë kontrollit të rregullimit të shërbyesit",
    "Non-existing tag #{tag}" : "Etiketë #{tag} që s’ekziston",
    "restricted" : "e kufizuar",
    "invisible" : "e padukshme",
    "({scope})" : "({scope})",
    "Delete" : "Fshije",
    "Rename" : "Riemërtoje",
    "Collaborative tags" : "Etiketa bashkëpunimi",
    "No tags found" : "Jo etiketime të gjetura",
    "unknown text" : "tekst i panjohur",
    "Hello world!" : "Hello world!",
    "sunny" : "me diell",
    "Hello {name}, the weather is {weather}" : "Tungjatjeta {name}, koha është {weather}",
    "Hello {name}" : "Tungjatjeta {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Këto janë rezultatet e juaj të kërkimit<script> alarm(1)",
    "new" : "i/e re",
    "_download %n file_::_download %n files_" : ["shkarko %n kartelë","shkarko %n kartela"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Përditësimi është në zhvillim, largimi nga faqja mund të ndërpres procesin në disa mjedise.",
    "Update to {version}" : "Përditëso në {version}",
    "An error occurred." : "Ndodhi një gabim.",
    "Please reload the page." : "Ju lutemi, ringarkoni faqen.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Përditësimi qe i pasuksesshëm. Për më tepër të dhëna <a href=\"{url}\">shihni postimin te forumi ynë</a> lidhur me këtë çështje.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Përditësimi ishte i pasuksesshëm. Ju lutem raportoni këtë problem në <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>.",
    "Continue to Nextcloud" : "Vazhdoni tek Nextcloud",
    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["Përditësimi ishte i suksesshëm. Ju ridrejtojmë në Nextcloud për %n sekonda.","Përditësimi ishte i suksesshëm. Ju ridrejtojmë në Nextcloud për %n sekonda."],
    "Searching other places" : "Duke kërkuar në vende të tjera",
    "No search results in other folders for {tag}{filter}{endtag}" : "Jo rezultate nga kërkimi në dosjet e tjera për '{etiketim}{filtrim}{përfundoetiketimin}'",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} përfundim kërkimi në një tjetër dosje","{count} përfundime kërkimi në dosje të tjera"],
    "Server side authentication failed!" : "Mirëfilltësimi më anë të shërbyesit dështoi!",
    "Please contact your administrator." : "Ju lutemi, lidhuni me përgjegjësin tuaj.",
    "An internal error occurred." : "Ndodhi një gabim i brendshëm.",
    "Please try again or contact your administrator." : "Ju lutemi, riprovoni ose lidhuni me përgjegjësin tuaj.",
    "Username or email" : "Emër përdoruesi ose email",
    "Password" : "Fjalëkalim",
    "Log in" : "Hyni",
    "Logging in …" : "Duke u loguar ...",
    "User disabled" : "Përdorues i çaktivizuar",
    "Reset password" : "Ricaktoni fjalëkalimin",
    "Couldn't send reset email. Please contact your administrator." : "S’u dërgua dot email-i i ricaktimit. Ju lutemi, lidhuni me përgjegjësin tuaj.",
    "Password can not be changed. Please contact your administrator." : "Fjalëkalimi nuk mund të ndryshohet. Ju lutemi, lidhuni me përgjegjësin tuaj.",
    "New password" : "Fjalëkalim i ri",
    "I know what I'm doing" : "E di se ç’bëj",
    "Forgot password?" : "Keni harruar fjalëkalimin?",
    "Settings" : "Rregullime",
    "Search contacts …" : "Kërko kontakte ...",
    "No contacts found" : "Nuk jane gjetur kontakte",
    "Show all contacts …" : "Shfaq të gjitha kontaktet",
    "Loading your contacts …" : "Kontaktet tuaja po ngarkohen ...",
    "Looking for {term} …" : "Duke kërkuar {për] ...",
    "No" : "Jo",
    "Yes" : "Po",
    "No files in here" : "Jo skedar këtu",
    "Choose" : "Zgjidhni",
    "Copy" : "Kopjo",
    "Move" : "Lëvize",
    "Error loading file picker template: {error}" : "Gabim në ngarkimin e gjedhes së marrësit të kartelave: {error}",
    "OK" : "OK",
    "Error loading message template: {error}" : "Gabim gjatë ngarkimit të gjedhes së mesazheve: {error}",
    "read-only" : "vetëm për lexim",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} përplasje kartelash","{count} përplasje kartelash"],
    "One file conflict" : "Një përplasje kartele",
    "New Files" : "Kartela të Reja",
    "Already existing files" : "Kartela ekzistuese",
    "Which files do you want to keep?" : "Cilat kartela doni të mbani?",
    "If you select both versions, the copied file will have a number added to its name." : "Nëse përzgjidhni të dy versionet, kartelës së kopjuar do t’i shtohet një numër në emrin e saj.",
    "Cancel" : "Anuloje",
    "Continue" : "Vazhdo",
    "(all selected)" : "(krejt të përzgjedhurat)",
    "({count} selected)" : "({count} të përzgjedhura)",
    "Error loading file exists template" : "Gabim në ngarkimin e gjedhes kartela ekziston",
    "Pending" : "Në pritje",
    "Saving..." : "Po ruhet …",
    "Authentication required" : "Verifikim i kërkuar",
    "This action requires you to confirm your password" : "Ky veprim kërkon që të konfirmoni fjalëkalimin tuaj.",
    "Confirm" : "Konfirmo",
    "Failed to authenticate, try again" : "Dështoi në verifikim, provo përsëri",
    "seconds ago" : "sekonda më parë",
    "Connection to server lost" : "Lidhja me serverin u shkëput",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem gjatë ngarkimit të faqes, rifreskimi në %n sekonda","Problem gjatë ngarkimit të faqes, rifreskimi në %n sekonda"],
    "New in" : "I ri në ",
    "No action available" : "Jo veprim i mundur",
    "Error fetching contact actions" : "Gabim gjatë marrjes së veprimeve të kontaktit",
    "Personal" : "Personale",
    "Users" : "Përdorues",
    "Apps" : "Aplikacione",
    "Admin" : "Admin",
    "Help" : "Ndihmë",
    "Access forbidden" : "Ndalohet hyrja",
    "File not found" : "S’u gjet kartelë",
    "Error" : "Gabim",
    "Internal Server Error" : "Gabim i Brendshëm Shërbyesi",
    "More details can be found in the server log." : "Më tepër hollësi mund të gjenden në regjistrin e shërbyesit.",
    "Technical details" : "Hollësi teknike",
    "Remote Address: %s" : "Adresë e Largët: %s",
    "Request ID: %s" : "ID Kërkese: %s",
    "Type: %s" : "Lloj: %s",
    "Code: %s" : "Kod: %s",
    "Message: %s" : "Mesazh: %s",
    "File: %s" : "Kartelë: %s",
    "Line: %s" : "Rresht: %s",
    "Trace" : "Gjurmim",
    "Security warning" : "Sinjalizim sigurie",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Drejtoria juaj e të dhënave dhe kartelat tuaja ka shumë mundësi të jenë të arritshme që nga interneti, ngaqë kartela .htaccess s’funksionon.",
    "Create an <strong>admin account</strong>" : "Krijoni një <strong>llogari administruesi</strong>",
    "Username" : "Emër përdoruesi",
    "Storage & database" : "Depozitë & bazë të dhënash",
    "Data folder" : "Dosje të dhënash",
    "Configure the database" : "Formësoni bazën e të dhënave",
    "Only %s is available." : "Vetëm %s është gati.",
    "Install and activate additional PHP modules to choose other database types." : "Që të zgjidhni të tjera lloje bazash të dhënash, instaloni dhe aktivizoni module PHP shtesë.",
    "For more details check out the documentation." : "Për më tepër të dhëna shihni dokumentimin.",
    "Database user" : "Përdorues baze të dhënash",
    "Database password" : "Fjalëkalim baze të dhënash",
    "Database name" : "Emër baze të dhënash",
    "Database tablespace" : "Tablespace-i i database-it",
    "Database host" : "Strehë baze të dhënash",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Ju lutem specifikoni numrin e portës së bashku me një emër hosti (p.sh. localhost:5432).",
    "Performance warning" : "Sinjalizim funksionimi",
    "Finish setup" : "Përfundoje rregullimin",
    "Finishing …" : "Po përfundohet …",
    "Need help?" : "Ju duhet ndihmë?",
    "See the documentation" : "Shihni dokumentimin",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Ky aplikacion lyp JavaScript për punim të saktë. Ju lutemi, {linkstart}aktivizoni JavaScript-in{linkend} dhe ringarkoni faqen.",
    "More apps" : "Më shumë aplikacione",
    "Search" : "Kërko",
    "Contacts" : "Kontaktet",
    "Contacts menu" : "Menuja e kontakteve",
    "Settings menu" : "Menuja e cilësimeve",
    "Confirm your password" : "Konfrimoni fjalëkalimin tuaj",
    "Connect to your account" : "Lidhuni me llogarinë tuaj",
    "App token" : "Çelës identifikues i API-t",
    "The password is wrong. Try again." : "Fjalëkalim i gabuar. Provojeni sërish.",
    "Two-factor authentication" : "Verifikim dy-element",
    "Use backup code" : "Përdorni kodin e kopjes rezervë",
    "Cancel log in" : "Anuloni identifikimin",
    "Error while validating your second factor" : "Gabim gjatë verifikimit të elementit të dytë",
    "App update required" : "Lypset përditësim aplikacioni",
    "These apps will be updated:" : "Do të përditësohen këto aplikacione:",
    "These incompatible apps will be disabled:" : "Do të çaktivizohen këto aplikacione të papërputhshme:",
    "The theme %s has been disabled." : "Tema %s u çaktivizua.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Ju lutemi, para se të vazhdoni më tej, sigurohuni që baza e të dhënave, dosja e formësimeve dhe dosja e të dhënave janë kopjeruajtur.",
    "Start update" : "Fillo përditësimin",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Për të shmangur çaste bllokimi pune me instalime të mëdha, mundeni të ekzekutoni urdhrin vijues që nga drejtoria juaj e instalimit:",
    "Detailed logs" : "Regjistrime të hollësishme",
    "Update needed" : "Lyp përditësim",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Ju lutemi,përdorni përditësuesin e rreshtit të urdhrave, sepse keni një instalim me mbi 50 përdorues",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Në qofte se unë vazhdoj të kryej përditësimin nëpëmjet web UI ka rrezik, që kërkesa mund të ndaloj dhe shkakton humbje të të dhënave, por unë di si ti rikthej të dhënat ne rast dështimi.",
    "Upgrade via web on my own risk" : "Përditëso me anë të internetit në rrezikun tim",
    "This %s instance is currently in maintenance mode, which may take a while." : "Kjo instancë %s hëpërhë gjendet nën mënyrën mirëmbajtje, çka mund të zgjasë ca.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Nëse ky mesazh shfaqet vazhdimisht ose u shfaq papritmas, lidhuni me përgjegjësin e sistemit.",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "S’u dërgua dot email ricaktimi, ngaqë s’ka adresë email për këtë përdoruesi. Ju lutemi, lidhuni me përgjegjësin tuaj.",
    "Couldn't send reset email. Please make sure your username is correct." : "S’u dërgua dot email ricaktimi. Ju lutemi, sigurohuni që emri juaj i përdoruesit është i saktë.",
    "Dismiss" : "Mos e merr parasysh",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Lidhja për ricaktimin e fjalëkalimi tuaj u dërgua tek email-i juaj. Nëse nuk e merrni brenda një kohe të arsyeshme, kontrolloni dosjet e postës së padëshirueshme/postës së pavlerë.<br>Nëse s’është as aty, pyetni përgjegjësin tuaj lokal.",
    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Skedarët tuaj janë të enkriptuar. Nuk do ketë asnjë mënyrë për ti rimarrë të dhënat pasi fjalëkalimi juaj të rivendoset. <br>Nëse nuk jeni të sigurt se çfarë duhet të bëni, ju lutemi flisni me administratorin tuaj para se të vazhdoni. <br /> Doni vërtet të vazhdoni?",
    "Shared" : "Ndarë",
    "Shared with" : "Ndarë me",
    "Shared by" : "Shpërndarë nga",
    "Choose a password for the public link" : "Zgjidhni një fjalëkalim për lidhjen publike",
    "Choose a password for the public link or press the \"Enter\" key" : "Zgjidhni një fjalëkalim për lidhjen publike ose shtypni butonin \"Enter\"",
    "Copied!" : "U kopjua!",
    "Not supported!" : "Jo i përshtatshëm!",
    "Press ⌘-C to copy." : "Shtyp ⌘-C për të kopjuar.",
    "Press Ctrl-C to copy." : "Shtypni Ctrl-C për të kopjuar.",
    "Resharing is not allowed" : "Nuk lejohen rindarjet",
    "Link" : "Lidhje",
    "Password protect" : "Mbroje me fjalëkalim",
    "Allow editing" : "Lejo përpunim",
    "Email link to person" : "Dërgoja personit lidhjen me email",
    "Send" : "Dërgo",
    "Allow upload and editing" : "Lejo ngarkim dhe editim",
    "Read only" : "Vetëm i lexueshëm",
    "File drop (upload only)" : "Lësho skedar (vetëm ngarkim)",
    "Set expiration date" : "Caktoni datë skadimi",
    "Expiration" : "Skadim",
    "Expiration date" : "Datë skadimi",
    "Unshare" : "Hiqe ndarjen",
    "Share to {name}" : "Ndaj tek {name}",
    "Share link" : "Lidhje ndarjeje",
    "Could not unshare" : "S’e shndau dot",
    "Shared with you and the group {group} by {owner}" : "Ndarë me ju dhe me grupin {group} nga {owner}",
    "Shared with you by {owner}" : "Ndarë me ju nga {owner}",
    "Choose a password for the mail share" : "Zgjidh një fjalëkalim për shpërndarjen e mail-it",
    "group" : "grup",
    "remote" : "i largët",
    "email" : "postë elektronike",
    "conversation" : "bisedë",
    "shared by {sharer}" : "ndarë nga {ndarësi}",
    "Can reshare" : "Mund të rishpërdajë",
    "Can edit" : "Mund të editojë",
    "Can create" : "Mund të krijoni",
    "Can change" : "Mund të ndryshojë",
    "Can delete" : "Mund të fshijë",
    "Access control" : "Kontrolli i aksesit",
    "Error while sharing" : "Gabim gjatë ndarjes",
    "Share details could not be loaded for this item." : "Për këtë objekt s’u ngarkuan dot hollësi ndarjeje.",
    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Të paktën {count} karaktere janë të nevojshëm për vetëpërmbushje","Të paktën {count} karaktere janë të nevojshëm për vetëpërmbushje"],
    "This list is maybe truncated - please refine your search term to see more results." : "Kjo listë ndoshta është e prerë - ju lutemi të përmirësoni termat e kërkimit tuaj për të parë më shumë rezultate.",
    "No users or groups found for {search}" : "S’u gjetën përdorues ose grupe për {search}",
    "No users found for {search}" : "S’u gjet përdorues për {search}",
    "An error occurred. Please try again" : "Ndodhi një gabim. Ju lutemi, riprovoni",
    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
    "Share" : "Ndaje",
    "Name or email address..." : "Emri ose adresa e email-it",
    "Name or federated cloud ID..." : "Emri ose ID e resë të fedferuar",
    "Name, federated cloud ID or email address..." : "Emri, ID e resë të federuar ose adresën e email-it...",
    "Name..." : "Emër",
    "Error removing share" : "Gabim në heqjen e ndarjes",
    "SQLite will be used as database." : "Si bazë të dhënash do të përdoret SQLite.",
    "For larger installations we recommend to choose a different database backend." : "Për instalime më të mëdha këshillojmë të zgjidhni një tjetër program shërbyesi baze të dhënash.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Përdorimi i SQLite-it shkëshillohet veçanërisht, kur për njëkohësim kartelash përdoret klienti desktop.",
    "Wrong password." : "Fjalëkalim i gabuar.",
    "New Password" : "Fjalëkalim i Ri"
},
"nplurals=2; plural=(n != 1);");
